pydevDAG._attributes._elementtypes module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._attributes package »

# pydevDAG._attributes._elementtypes module

## pydevDAG._attributes._elementtypes

Types of graph elements.

class `pydevDAG._attributes._elementtypes.` `ElementType`

  Bases: `pydevDAG._attributes._metaclasses.AttributeValue`

  Abstract class that represents a graph element type.

class `pydevDAG._attributes._elementtypes.` `ElementTypes`

  Bases: `pydevDAG._attributes._metaclasses.AttributeValues`

  Enumeration of element types.

  `EDGE` = Edge()
  `NODE` = Node()
  classmethod `values`()

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._attributes package »